# pyOgero: Ogero API Python module

[![PyPI Latest Release](https://img.shields.io/pypi/v/pyogero)](https://pypi.org/project/pyogero/)
[![Package Status](https://img.shields.io/pypi/status/pyogero)](https://pypi.org/project/pyogero/)
[![GitHub branch checks state](https://img.shields.io/github/checks-status/oraad/pyogero/main)](https://github.com/oraad/pyogero/)
[![License](https://img.shields.io/pypi/l/pyogero)](https://github.com/oraad/pyogero/blob/main/LICENSE)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000)](https://github.com/psf/black)

Ogero does not currently provide a rest api to access it services,
therefore this module web scrap the mobile version of the pages to collect data.
